import { BlankTemplateView, PageTemplateView, TabsTemplateView } from '@/pages/frame/view/template';

// 路由配置
const options = {
    mode: 'history',
    routes: [
        {
            path: '/login',
            name: '登录页',
            component: () => import('@/pages/frame/view/login'),
        },
        {
            path: '*',
            name: '404',
            component: () => import('@/pages/frame/view/exception/404'),
        },
        {
            path: '/403',
            name: '403',
            component: () => import('@/pages/frame/view/exception/403'),
        },
        {
            path: '/500',
            name: '500',
            component: () => import('@/pages/frame/view/exception/500'),
        },
        {
            path: '/',
            component: TabsTemplateView,
            redirect: '/home',
            name: '首页',
            children: [
                {
                    path: 'home',
                    name: '首页',
                    meta: { icon: 'home' },
                    component: () => import('@/pages/home/index.vue'),
                },
                {
                    path: 'dashboard',
                    name: 'Dashboard',
                    meta: {
                        icon: 'dashboard',
                    },
                    component: BlankTemplateView,
                    children: [
                        {
                            path: 'workbench',
                            name: '工作台',
                            meta: {
                                page: {
                                    closable: false,
                                },
                            },
                            component: () => import('@/pages/dashboard/workbench'),
                        },
                        {
                            path: 'analysis',
                            name: '分析页',
                            component: () => import('@/pages/dashboard/analysis'),
                        },
                    ],
                },
                {
                    path: 'system_management',
                    name: '系统管理',
                    meta: {
                        icon: 'setting',
                        page: {
                            cacheAble: true,
                        },
                    },
                    component: PageTemplateView,
                    children: [
                        {
                            path: 'menu_management',
                            name: '菜单管理',
                            component: () => import('@/pages/system/view/menu'),
                        },
                        {
                            path: 'organization_management',
                            name: '组织管理',
                            component: BlankTemplateView,
                            children: [
                                {
                                    path: 'job_management',
                                    name: '岗位管理',
                                    component: () =>
                                        import('@/pages/system/view/organization/jobsmanagement/Jobs.vue'),
                                },
                                {
                                    path: 'user_management',
                                    name: '用户管理',
                                    component: () =>
                                        import('@/pages/system/view/organization/usermanagement/User.vue'),
                                },
                                {
                                    path: 'org_management',
                                    name: '机构管理',
                                    component: () =>
                                        import('@/pages/system/view/organization/orgmanagement/Org.vue'),
                                },
                            ],
                        },
                        {
                            path: 'role_management',
                            name: '角色管理',
                            component: () => import('@/pages/system/view/role'),
                        },
                        {
                            path: 'parameter_management',
                            name: '参数管理',
                            component: () => import('@/pages/system/view/parameter'),
                        },
                        {
                            path: 'log_management',
                            name: '日志管理',
                            component: BlankTemplateView,
                            children: [
                                {
                                    path: 'login_log',
                                    name: '登录日志',
                                    component: () => import('@/pages/system/view/log/login_log/index.vue'),
                                },
                            ],
                        },
                        {
                            path: 'task_management',
                            name: '任务管理',
                            component: () => import('@/pages/system/view/task/index.vue'),
                        },
                    ],
                },
                {
                    path: 'user_center',
                    name: '个人中心',
                    meta: { icon: 'user' },
                    component: () => import('@/pages/user/index.vue'),
                },
            ],
        },
    ],
};

export default options;
